#!/usr/bin/env python3

"""The setup script."""

# Third party modules
from setuptools import setup

setup(name='cheeseshop',
      version='0.0.0',
      description='place holder',
      url='http://github.com/SK/cheeseshop',
      author='sking',
      author_email='flyingcircus@example.com',
      license='MIT',
      packages=['cheeseshop'],
      zip_safe=False)